<?php
/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    lead_capture
 * @subpackage lead_capture/includes
 * @author     Kamleshyadav <#>
 */
class Lead_capture {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      lead_capture_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'LEAD_CAPTURE' ) ) {
			$this->version = LEAD_CAPTURE;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'lead_capture_formbuilder';

		$this->lead_capture_form_load_dependencies();
		$this->lead_capture_form_set_locale();
		$this->lead_capture_form_define_admin_hooks();
		$this->lead_capture_form_define_public_hooks();
		add_action('admin_menu', array($this, 'lead_capture_formbuilder_menus') );
		add_action( 'admin_head', array($this, 'lead_capture_form_hide_add_new_form_page') );
	
	}
	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Lead_capture_Loader. Orchestrates the hooks of the plugin.
	 * - Lead_capture_i18n. Defines internationalization functionality.
	 * - Lead_capture_admin. Defines all hooks for the admin area.
	 * - Lead_capture_public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function lead_capture_form_load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/lead-capture-class-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/lead-capture-class-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/lead-capture-class-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/lead-capture-class-public.php';

		$this->loader = new Lead_capture_loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the lead_capture_formbuilder_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function lead_capture_form_set_locale() {

		$plugin_i18n = new Lead_capture_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function lead_capture_form_define_admin_hooks() {

		$plugin_admin = new Lead_capture_admin( $this->lead_capture_form_get_plugin_name(), $this->lead_capture_form_get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function lead_capture_form_define_public_hooks() {

		$plugin_public = new Lead_capture_public( $this->lead_capture_form_get_plugin_name(), $this->lead_capture_form_get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function lead_capture_form_get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    'Lead_capture_loader'   
	 *  Orchestrates the hooks of the plugin.
	 */
	public function lead_capture_form_get_loader() {
		return $this->loader;
	}
	
	public function lead_capture_formbuilder_menus(){
			$pageTitle = isset($_GET['action']) && $_GET['action'] == 'edit' ? __( 'Edit Form', 'lead_capture_form' ) : __( 'ALL Forms', 'lead_capture_form' );
			
			add_menu_page( 
				__( 'Lead Capture', 'lead_capture_form' ),
				__( 'Lead Capture', 'lead_capture_form' ),
				'manage_options',
				'lead_capture',
				array($this,'lead_capture_templates'),
				'dashicons-admin-page',
				2
			);
			
			add_submenu_page( 
				'',
				__( 'Form Builder', 'lead_capture_form' ),
				__( 'Form Builder', 'lead_capture_form' ),
				'manage_options',
				'form-builder',
				array($this,'lead_capture_form_main_page')
			);
			
			add_submenu_page( 
				'lead_capture',
				$pageTitle,
				__( 'Forms', 'lead_capture_form' ),
				'manage_options',
				'lead_capture_form-forms',
				array($this,'lead_capture_form_main_all_forms')
			);
		
			
			add_submenu_page(
				'lead_capture',
				__( 'Form Data', 'lead_capture_form' ),
				__( 'Form Data', 'lead_capture_form' ),
				'manage_options',
				'lead_capture_form-form-data',
				array($this,'lead_capture_form_database')
			);
			
			add_submenu_page(
				'lead_capture',
				__( 'Templates', 'lead_capture_form' ),
				__( 'Templates', 'lead_capture_form' ),
				'manage_options',
				'lead_capture_template',
				array($this,'lead_capture_templates')
			);

			remove_submenu_page( 'lead_capture', 'lead_capture' );
			remove_submenu_page( 'form-builder', 'form-builder' );
			
			add_submenu_page( 
				'lead_capture',
				__( 'Autoresponders', 'lead_capture_form' ),
				__( 'Autoresponders', 'lead_capture_form' ),
				'manage_options',
				'lead_capture_form-autoresponder',
				array($this,'lead_capture_form_autoresponder')
			);
	}

	public function lead_capture_form_autoresponder(){
		$autoresponder = get_option('lead_capture_form_autoresponder_settings');
		$CustomHtml = get_option('lead_capture_form_custom_html_settings');
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/autoresponder/autoresponder.php';
	}
	
	public function lead_capture_form_hide_add_new_form_page(){
		remove_submenu_page( 'lead_capture_form-form', 'form-builder' );
	}
		
	public function lead_capture_form_main_page(){
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/lead-capture-mainpage.php';
	}
	
	public function lead_capture_form_main_all_forms(){
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/lead-capture-all-froms-render.php';
	}
	
	public function lead_capture_form_main_addnew(){
		$this->lead_capture_form_main_page();
	}
	
	/***** Form Database Tabel *****/
	public function lead_capture_form_database(){
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/lead-capture-datatable.php';
	}

	/***** Templates Tabel *****/
	public function lead_capture_templates(){
		global $wpdb;
		$rowperpage = 8;
		$templates = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}lead_capture_pages_templates limit 0,$rowperpage", OBJECT );
		$all_templates = $wpdb->get_results( "SELECT COUNT(id) as total_template FROM {$wpdb->prefix}lead_capture_pages_templates", OBJECT );
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/lead-capture-templates.php';
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function lead_capture_form_get_version() {
		return $this->version;
	}

}